/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apithefire.util.lang;

/**
 * A {@link Builder} builds a complex object step by step.
 * 
 * <pre>
 * Building building = Building.newBuilder().setWidth(10).setHeight(10).build();
 * </pre>
 * 
 * <p>
 * Normally a {@link Builder} is instantiated via
 * {@linkplain BuilderFactory builder factory method}.
 * </p>
 * 
 * <pre>
 * &#064;{@link BuilderFactory}
 * public static BuildingBuilder newBuilder() {
 * 	return new BuildingBuilder();
 * }
 * </pre>
 * 
 * @author <a href="mailto:bachew@gmail.com">Chew Boon Aik</a>
 */
public interface Builder {

	/**
	 * Builds a new object.
	 * 
	 * @return the built object.
	 */
	public Object build();
	
}
