/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apithefire.util.lang;

/**
 * Utility class related to {@link Object}.
 * 
 * @author <a href="mailto:bachew@gmail.com">Chew Boon Aik</a>
 */
public class Objects {

	private Objects() {
	}

	/**
	 * Returns passed in argument {@code obj} or throws
	 * {@link NullPointerException} if {@code obj} is null.
	 */
	public static <T> T nonNull(T obj) {
		if (obj == null) {
			throw new NullPointerException();
		}
		return obj;
	}

	/**
	 * Returns true if both {@code obj1} and {@code obj2} are both nulls or
	 * {@code obj1} and {@code obj2} are equal, false otherwise.
	 */
	public static boolean equal(@Nullable Object obj1, @Nullable Object obj2) {
		return (obj1 == null && obj2 == null)
				|| (obj1 != null && obj2 != null && obj1.equals(obj2));
	}
	
	/**
	 * Returns {@code obj.toString()} if {@code} is not null, {@code "null"}
	 * otherwise.
	 */
	public static String toString(@Nullable Object obj) {
		return obj == null ? "null" : obj.toString();
	}

}
