/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apithefire.util.lang;

import java.io.File;

/**
 * A {@link Platform} represents an operating system and an environment.
 * 
 * @author <a href="mailto:bachew@gmail.com">Chew Boon Aik</a>
 */
// TODO: replace this class with Systems
public class Platform {
	
	private static final String SP_OS_NAME = "os.name";
	private static final String SP_USER_NAME = "user.name";
	private static final String SP_USER_HOME = "user.home";

	private static Platform platform;
	
	private File userHomeDirectory;
	
	/**
	 * Gets current platform.
	 */
	public static Platform getInstance() {
		if (platform == null) {
			platform = new Platform();
		}
		return platform;
	}
	
	protected Platform() {
	}
	
	/**
	 * Returns operating system's name.
	 */
	public String getOsName() {
		return System.getProperty(SP_OS_NAME);
	}
	
	/**
	 * Returns user's name.
	 */
	public String getUserName() {
		return System.getProperty(SP_USER_NAME);
	}
	
	/**
	 * Return user's home directory.
	 */
	public File getUserHomeDirectory() {
		if (userHomeDirectory == null) {
			userHomeDirectory = new File(System.getProperty(SP_USER_HOME));
		}
		return userHomeDirectory;
	}
	
}
