/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apithefire.util.lang;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * Utility class related to {@link System}.
 * 
 * @author <a href="mailto:bachew@gmail.com">Chew Boon Aik</a>
 */
public class Systems {

	private static final String SP_PATH_SEPARATOR = "path.separator";
	private static final String SP_CLASS_PATH = "java.class.path";
	
	private static List<String> classPath;
	
	/**
	 * Returns {@link System}'s path separator.
	 */
	public static String getPathSeparator() {
		return Strings.nullIfEmpty(System.getProperty(SP_PATH_SEPARATOR));
	}
	
	/**
	 * Return {@link System}'s class path.
	 */
	public static List<String> getClassPath() {
		if (classPath == null) {
			String classPathStr = Strings.nullIfEmpty(System
					.getProperty(SP_CLASS_PATH));
			
			if (classPathStr == null) {
				classPath = Collections.emptyList();
			} else {
				String separator = getPathSeparator();
				Path tmpPath = Path.split(classPathStr, separator);
				
				if (tmpPath.isEmpty()) {
					classPath = Collections.emptyList();
				} else {
					List<String> tmpClassPath = new ArrayList<String>();
					
					for (int i = 0; i < tmpPath.length(); ++i) {
						tmpClassPath.add(tmpPath.componentAt(i));
					}
					classPath = Collections.unmodifiableList(tmpClassPath);
				}
			}
		}
		return classPath;
	}
	
}
