/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apithefire.util.net;

import java.io.IOException;
import java.lang.reflect.Method;
import java.net.URI;

import org.apithefire.util.lang.Platform;

public class BrowserLauncher {

	/**
	 * Open browser with the specified URI.
	 * 
	 * @returns false if an error occurs, true otherwise
	 */
	public static boolean open(URI uri) {

		String osName = Platform.getInstance().getOsName();
		
		if (osName.startsWith("Mac OS")) {
			return macOpen(uri);
		} else if (osName.startsWith("Windows")) {
			return windowsOpen(uri);
		} else {
			return unixOpen(uri);
		}
	}
	
	public static boolean macOpen(URI uri) {
		try {
			Class<?> fileManagerClass = Class.forName("com.apple.eio.FileManager");
			Method openUrlMethod = fileManagerClass.getDeclaredMethod("openURL",
					new Class[] { String.class });
			openUrlMethod.invoke(null, uri.toString());
			return true;
		} catch (Exception e) {
			return false;
		}
	}
	
	public static boolean windowsOpen(URI uri) {
		Runtime runtime = Runtime.getRuntime();
		try {
			runtime.exec("rundll32 url.dll,FileProtocolHandler "
					+ uri.toString());
			return true;
		} catch (IOException e) {
			return false;
		}
	}
	
	public static boolean unixOpen(URI uri) {
		String[] browsers = { "firefox", "opera", "konqueror",
				"epiphany", "mozilla", "netscape" };
		
		Runtime runtime = Runtime.getRuntime();

		for (String browser : browsers) {
			try {
				Process process = runtime
						.exec(new String[] { "which", browser });

				if (process.waitFor() == 0) {
					runtime.exec(new String[] { browser, uri.toString() });
					return true;
				}
			} catch (IOException e) {
				continue;
			} catch (InterruptedException e) {
				continue;
			}
		}
		return false;
	}
	
}
