/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apithefire.util.net;

import java.io.UnsupportedEncodingException;
import java.net.URI;

import org.apithefire.util.nio.Charsets;

/**
 * Utility class related to {@link URI}.
 * 
 * @author <a href="mailto:bachew@gmail.com">Chew Boon Aik</a>
 */
public class URIs {

    private static final char[] HEX_CHARS = { 
            '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 
            'A', 'B', 'C', 'D', 'E', 'F' };

	/**
	 * Encodes the specified string by percent-encode non-unreserved characters.
	 * Unreserved characters are uppercase and lowercase letters, decimal
	 * digits, hyphen, period, underscore, and tilde.
	 * 
	 * @return the encoded string
	 */
	public static String encode(String str) {
		StringBuilder result = new StringBuilder();
		byte[] bytes = null;
		
		try {
			// XXX: changed from String.getBytes(Charset) to
			// String.getBytes(String) to compile in JDK 1.5
			bytes = str.getBytes(Charsets.UTF_8.name());
		} catch (UnsupportedEncodingException e) {
			throw new RuntimeException(e);
		}
		
		for (byte b : bytes) {
			int ch = 0 | b;
			
			if (isSafeCode(ch)) {
				result.append((char) ch);
			} else {
				result.append('%');
				result.append(HEX_CHARS[((ch & 0xF0) >> 4)]);
				result.append(HEX_CHARS[ch & 0x0F]);
			}
		}
		return result.toString();
	}
	
	public static boolean isSafeCode(int code) {
		return Character.isLetterOrDigit(code)
			|| code == '-'
			|| code == '.'
			|| code == '_'
			|| code == '~';
	}
	
}
