/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apithefire.util.resource;

import java.io.IOException;
import java.io.InputStream;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.jar.JarEntry;
import java.util.jar.JarFile;

import org.apithefire.util.lang.Objects;
import org.apithefire.util.lang.Path;
import org.apithefire.util.lang.StringRepr;

class ContentJarResource implements Resource {
	
	private final JarFile jarFile;
	private final JarEntry jarEntry;
	
	public ContentJarResource(JarFile jarFile, JarEntry jarEntry) {
		this.jarFile = Objects.nonNull(jarFile);
		this.jarEntry = Objects.nonNull(jarEntry);
	}
	
	public boolean isDirectory() {
		return false;
	}

	public Collection<String> list() {
		return Collections.emptyList();
	}

	public Resource getResource(Path path) {
		throw new ResourceNotFoundException(this, path);
	}
	
	public boolean isFile() {
		return true;
	}

	public Date getFileModifiedTime() {
		return new Date(jarEntry.getTime());
	}

	public long getFileSize() {
		long length = jarEntry.getSize();
		
		return length > 0 ? length : 0;
	}

	public InputStream openFile() {
		try {
			return jarFile.getInputStream(jarEntry);
		} catch (IOException e) {
			throw new ResourceException(e);
		}
	}
	
	@Override
	public String toString() {
		return StringRepr.fromObject(this)
				.add("jarFile", jarFile)
				.add("path", jarEntry.getName())
				.toString();
	}

}
