/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apithefire.util.resource;

import java.io.InputStream;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;

import org.apithefire.util.lang.Path;
import org.apithefire.util.lang.StringRepr;

class EmptyDirectoryResource implements Resource {
	
	public boolean isDirectory() {
		return true;
	}

	public Collection<String> list() {
		return Collections.emptyList();
	}

	public Resource getResource(Path path) {
		throw new ResourceNotFoundException(this, path);
	}
	
	public boolean isFile() {
		return false;
	}
	
	public Date getFileModifiedTime() {
		return null;
	}
	
	public long getFileSize() {
		return -1;
	}

	public InputStream openFile() {
		// TODO: throw NotAFileException?
		throw new ResourceException("Can not open a directory resource.");
	}
	
	@Override
	public String toString() {
		return StringRepr.fromObject(this).toString();
	}
	
}
