/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apithefire.util.slf4j;

import org.apithefire.util.lang.Objects;
import org.slf4j.Logger;

/**
 * Utility class related to {@link Logger}
 * 
 * @author <a href="mailto:bachew@gmail.com">Chew Boon Aik</a>
 */
public class Loggers {
	
	private static final String ARG_PLACEHOLDER = "{}";
	private static final int ARG_PLACEHOLDER_LEN = ARG_PLACEHOLDER.length();
	
	/**
	 * Equivalent to
	 * {@linkplain format(String, Object[]) format(format, new Object[] { arg })}.
	 */
	public static String format(String format, Object arg) {
		return format(format, new Object[] { arg });
	}
	
	/**
	 * Formats message for use in {@link Logger} format methods.
	 * 
	 * @param format format string
	 * @param args arguments
	 * @return formatted message
	 */
	public static String format(String format, Object... args) {
		int prevArgIndex = -ARG_PLACEHOLDER_LEN;
		int argIndex = format.indexOf(ARG_PLACEHOLDER);
		
		if (argIndex == -1) {
			return format;
		}
		
		StringBuilder message = new StringBuilder(format.length() * 2);
		
		for (int i = 0; prevArgIndex < format.length(); ++i) {
			message.append(format.substring(prevArgIndex
					+ ARG_PLACEHOLDER_LEN, argIndex));
			
			if (i < args.length && argIndex < format.length()) {
				message.append(Objects.toString(args[i]));
			}
			prevArgIndex = argIndex;
			argIndex = format.indexOf(ARG_PLACEHOLDER, argIndex
					+ ARG_PLACEHOLDER_LEN);
			
			if (argIndex == -1) {
				argIndex = format.length();
			}
		}
		return message.toString();
	}

}
